<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>  
Estonian_LO_main
</name>

<description>  
Estonian LibreOffice Language Meta-Package (no database)
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>
echo "---- in preprocessing ----"
echo "---- preprocessing done----"
</preinstall>

<install_package_names>
libreoffice-calc
libreoffice-draw
libreoffice-impress
libreoffice-math
libreoffice-writer
libreoffice-l10n-et
libreoffice-help-et
libreoffice-gtk
</install_package_names>

<postinstall>

</postinstall>

<uninstall_package_names>
libreoffice-calc
libreoffice-draw
libreoffice-impress
libreoffice-math
libreoffice-writer
libreoffice-l10n-et
libreoffice-help-et
libreoffice-gtk
</uninstall_package_names>

</app>
